@@ -1,9 +1,10 @@
+from __future__ import annotations
+
 from collections.abc import Callable
 from dataclasses import dataclass
 from functools import wraps
 from typing import Any, Generic, TypeVar, cast
 
-from beartype import beartype
 from memory_profiler import memory_usage
 from typing_extensions import ParamSpec
 
@@ -11,7 +12,6 @@ _P = ParamSpec("_P")
 _T = TypeVar("_T")
 
 
-@beartype
 @dataclass(frozen=True)
 class Output(Generic[_T]):
     """A function output, and its memory usage."""
@@ -20,7 +20,6 @@ class Output(Generic[_T]):
     memory: float
 
 
-@beartype
 def memory_profiled(func: Callable[_P, _T], /) -> Callable[_P, Output[_T]]:
     """Call a function, but also profile its maximum memory usage."""
 
@@ -32,3 +31,6 @@ def memory_profiled(func: Callable[_P, _T], /) -> Callable[_P, Output[_T]]:
         return Output(value=value, memory=memory)
 
     return wrapped
+
+
+__all__ = ["Output", "memory_profiled"]
